@@ -10,7 +10,7 @@ logging.basicConfig(
 
 
 class RedisConnect:
-    def __init__(self, db: int, host_key='REDIS_HOST', port_key='REDIS_PORT', decode_responses: bool = True, *args, **kwargs):
+    def __init__(self, db=0, host_key='REDIS_HOST', port_key='REDIS_PORT', decode_responses: bool = True, *args, **kwargs):
         self.redis_host = os.environ.get(host_key, '127.0.0.1')
         self.redis_port = os.environ.get(port_key, 6379)
         # 创建Redis连接池
@@ -121,3 +121,10 @@ class RedisConnect:
         exists_('zset1')
         """
         return self.connect().exists(*args)
+
+    def expire_(self, *args, **kwargs):
+        """
+        设置超时时间
+        expire_('list5', time=3)
+        """
+        return self.connect().expire(*args, **kwargs)
